@@ -6,7 +6,7 @@ use Alien::Build::Plugin;
 use Carp ();
 
 # ABSTRACT: Probe system and determine library or tool properties using the pkg-config command line interface
-our $VERSION = '0.55'; # VERSION
+our $VERSION = '0.57'; # VERSION
 
 
 has '+pkg_name' => sub {
@@ -17,12 +17,12 @@ has bin_name => sub {
 
   # We prefer pkgconf to pkg-config because it seems to be the future.
 
-  require IPC::Cmd;
-  IPC::Cmd::can_run($ENV{PKG_CONFIG})
+  require File::Which;
+  File::Which::which($ENV{PKG_CONFIG})
     ? $ENV{PKG_CONFIG}
-    : IPC::Cmd::can_run('pkgconf')
+    : File::Which::which('pkgconf')
       ? 'pkgconf'
-      : IPC::Cmd::can_run('pkg-config')
+      : File::Which::which('pkg-config')
         ? 'pkg-config'
         : undef;
 };
@@ -105,7 +105,7 @@ Alien::Build::Plugin::PkgConfig::CommandLine - Probe system and determine librar
 
 =head1 VERSION
 
-version 0.55
+version 0.57
 
 =head1 SYNOPSIS
 
