@@ -5,22 +5,35 @@ use warnings;
 use 5.008001;
 use Env qw( @PATH );
 use File::Which 1.10 qw( which );
-use Capture::Tiny qw( capture capture_merged );
+use if $^O ne 'MSWin32', 'Capture::Tiny' => 'capture_merged';
+use Capture::Tiny qw( capture );
 use File::Temp ();
 use Carp qw( croak );
+use File::Spec;
 use File::Basename qw( dirname );
+use File::Path qw( mkpath );
 use File::Copy qw( move );
 use Text::ParseWords qw( shellwords );
 use Test2::API qw( context run_subtest );
 use base qw( Exporter );
-use Path::Tiny qw( path );
-use Alien::Build::Util qw( _dump );
+
+BEGIN {
+  *capture_merged = sub (&;@)
+  {
+    # TODO: fix this error properly:
+    #Error in tempfile() using template C:\Users\ollisg\AppData\Local\Temp\XXXXXXXXXX: Could not create temp file C:\Users\ollisg\AppData\Local\Temp\eysiq7e9w5: Permission denied at N:/home/ollisg/perl5/straw
+    # rry/x86/5.22.1/lib/perl5/Capture/Tiny.pm line 360.
+    
+    # this seems to work more reliably on windows, at the cost of being much noisier.
+    my $code = shift;
+    wantarray ? ('', $code->(@_)) : '';
+  } if $^O eq 'MSWin32';
+}
 
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic helper_ok interpolate_template_is );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '0.98_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '0.57'; # VERSION
 
 
 our @aliens;
@@ -30,37 +43,23 @@ sub alien_ok ($;$)
   my($alien, $message) = @_;
 
   my $name = ref $alien ? ref($alien) . '[instance]' : $alien;
-  $name = 'undef' unless defined $name;
+  
   my @methods = qw( cflags libs dynamic_libs bin_dir );
   $message ||= "$name responds to: @methods";
+  my @missing = grep { ! $alien->can($_) } @methods;
   
-  my $ok;
-  my @diag;
-  
-  if(defined $alien)
-  {
-    my @missing = grep { ! $alien->can($_) } @methods;
-  
-    $ok = !@missing;
-    push @diag, map { "  missing method $_" } @missing;
-
-    if($ok)
-    {
-      push @aliens, $alien;
-      unshift @PATH, $alien->bin_dir;
-    }
-  }
-  else
-  {
-    $ok = 0;
-    push @diag, "  undefined alien";
-  }
-
+  my $ok = !@missing;
   my $ctx = context();
   $ctx->ok($ok, $message);
-  $ctx->diag($_) for @diag;
+  $ctx->diag("  missing method $_") for @missing;
   $ctx->release;
   
+  if($ok)
+  {
+    push @aliens, $alien;
+    unshift @PATH, $alien->bin_dir;
+  }
+  
   $ok;
 }
 
@@ -143,31 +142,11 @@ sub _flags
 {
   my($class, $method) = @_;
   my $static = "${method}_static";
-  $class->can($static) && $class->can('install_type') && $class->install_type eq 'share' && (!$class->can('xs_load'))
+  $class->can($static) && $class->can('install_type') && $class->install_type eq 'share'
     ? $class->$static
     : $class->$method;
 }
 
-{
-  my $seen = 0;
-  sub _warn_cpp
-  {
-    return if $seen;
-    my $ctx = context();
-    $ctx->diag('');
-    $ctx->diag('');
-    $ctx->diag(' !!!');
-    $ctx->diag('');
-    $ctx->diag("Test::Alien xs_ok C++ is DEPRECATED and will be removed on or after 31 August 2017");
-    $ctx->diag("Please use Test::Alien::CPP instead");
-    $ctx->diag('');
-    $ctx->diag(' !!!');
-    $ctx->diag('');
-    $ctx->release;
-    $seen++;
-  }
-}
-
 sub xs_ok
 {
   my $cb;
@@ -192,27 +171,12 @@ sub xs_ok
   # modify it.
   $xs->{xs} = "@{[ $xs->{xs} ]}";
   $xs->{pxs} ||= {};
-  $xs->{cbuilder_compile} ||= {};
-  $xs->{cbuilder_link}    ||= {};
-
-  if($xs->{cpp} || $xs->{'C++'})
-  {
-    _warn_cpp();
-    $xs->{pxs}->{'C++'} = 1;
-    $xs->{cbuilder_compile}->{'C++'} = 1;
-    $xs->{c_ext} = 'cpp';
-  }
-  else
-  {
-    $xs->{c_ext} = 'c';
-  }
-
-  my $verbose = $xs->{verbose} || 0;
+  my $verbose = $xs->{verbose};
   my $ok = 1;
   my @diag;
   my $dir = _tempdir( CLEANUP => 1, TEMPLATE => 'testalienXXXXX' );
-  my $xs_filename = path($dir)->child('test.xs')->stringify;
-  my $c_filename  = path($dir)->child("test.@{[ $xs->{c_ext} ]}")->stringify;
+  my $xs_filename = File::Spec->catfile($dir, 'test.xs');
+  my $c_filename  = File::Spec->catfile($dir, 'test.c');
   
   my $ctx = context();
   my $module;
@@ -281,15 +245,12 @@ sub xs_ok
   {
     my $cb = ExtUtils::CBuilder->new;
 
-    my %compile_options = (
-      source               => $c_filename,
-      extra_compiler_flags => [shellwords map { _flags $_, 'cflags' } @aliens],
-      %{ $xs->{cbuilder_compile} },
-    );
-
     my($out, $obj, $err) = capture_merged {
       my $obj = eval {
-        $cb->compile(%compile_options);
+        $cb->compile(
+          source               => $c_filename,
+          extra_compiler_flags => [shellwords map { _flags $_, 'cflags' } @aliens],
+        );
       };
       ($obj, $@);
     };
@@ -297,11 +258,6 @@ sub xs_ok
     $ctx->note("compile $c_filename") if $verbose;
     $ctx->note($out) if $verbose;
     $ctx->note($err) if $verbose && $err;
-
-    if($verbose > 1)
-    {
-      $ctx->note(_dump({ compile_options => \%compile_options }));
-    }
     
     unless($obj)
     {
@@ -313,17 +269,14 @@ sub xs_ok
     
     if($ok)
     {
-
-      my %link_options = (
-        objects            => [$obj],
-        module_name        => $module,
-        extra_linker_flags => [shellwords map { _flags $_, 'libs' } @aliens],
-        %{ $xs->{cbuilder_link} },
-      );
-
+    
       my($out, $lib, $err) = capture_merged {
         my $lib = eval { 
-          $cb->link(%link_options);
+          $cb->link(
+            objects            => [$obj],
+            module_name        => $module,
+            extra_linker_flags => [shellwords map { _flags $_, 'libs' } @aliens],
+          );
         };
         ($lib, $@);
       };
@@ -331,13 +284,8 @@ sub xs_ok
       $ctx->note("link $obj") if $verbose;
       $ctx->note($out) if $verbose;
       $ctx->note($err) if $verbose && $err;
-
-      if($verbose > 1)
-      {
-        $ctx->note(_dump({ link_options => \%link_options }));
-      }
-
-      if($lib && -f $lib)
+      
+      if($lib)
       {
         $ctx->note("created lib $lib") if $xs->{verbose};
       }
@@ -356,44 +304,25 @@ sub xs_ok
         my $dl_dlext = $Config::Config{dlext};
         my $modfname = $modparts[-1];
 
-        my $libpath = path($dir)->child('auto', @modparts, "$modfname.$dl_dlext");
-        $libpath->parent->mkpath;
-        move($lib, "$libpath") || die "unable to copy $lib => $libpath $!";
+        my $libpath = File::Spec->catfile($dir, 'auto', @modparts, "$modfname.$dl_dlext");
+        mkpath(dirname($libpath), 0, 0700);
+        move($lib, $libpath) || die "unable to copy $lib => $libpath $!";
         
         pop @modparts;
-        my $pmpath = path($dir)->child(@modparts, "$modfname.pm");
-        $pmpath->parent->mkpath;
-        open my $fh, '>', "$pmpath";
-        
-        my($alien_with_xs_load, @rest) = grep { $_->can('xs_load') } @aliens;
-        
-        if($alien_with_xs_load)
-        {
-          print $fh '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) . qq{
-            package $module;
-            
-            use strict;
-            use warnings;
-            
-            $alien_with_xs_load->xs_load('$module', '\$VERSION', @rest);
-            
-            1;
-          };
-        }
-        else
-        {
-          print $fh '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) . qq{
-            package $module;
+        my $pmpath = File::Spec->catfile($dir, @modparts, "$modfname.pm");
+        mkpath(dirname($pmpath), 0, 0700);
+        open my $fh, '>', $pmpath;
+        print $fh '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) . qq{
+          package $module;
           
-            use strict;
-            use warnings;
-            require XSLoader;
-            our \$VERSION = '0.01';
-            XSLoader::load('$module','\$VERSION');
+          use strict;
+          use warnings;
+          require XSLoader;
+          our \$VERSION = '0.01';
+          XSLoader::load('$module','\$VERSION');
           
-            1;
-          };
-        }
+          1;
+        };
         close $fh;
 
         {
@@ -607,7 +536,7 @@ sub _tempdir {
 
   if($^O ne 'MSWin32')
   {
-    my $filename = path($dir, 'foo.pl');
+    my $filename = File::Spec->catfile($dir, 'foo.pl');
     my $fh;
     open $fh, '>', $filename;
     print $fh "#!$^X";
@@ -616,7 +545,7 @@ sub _tempdir {
     system $filename, 'foo';
     if($?)
     {
-      $dir = File::Temp::tempdir( DIR => path('.')->absolute->stringify );
+      $dir = File::Temp::tempdir( DIR => File::Spec->curdir );
     }
   }
   
@@ -637,7 +566,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 0.98_01
+version 0.57
 
 =head1 SYNOPSIS
 
@@ -801,10 +730,6 @@ List reference containing the dynamic libraries.
 
 Tool binary directory.
 
-=item runtime_prop
-
-Runtime properties.
-
 =back
 
 See L<Test::Alien::Synthetic> for more details.
@@ -848,26 +773,12 @@ The XS code.  This is the only required element.
 
 =item pxs
 
-Extra L<ExtUtils::ParseXS> arguments passed in as a hash reference.
-
-=item cbuilder_compile
-
-Extra The L<ExtUtils::CBuilder> arguments passed in as a hash reference.
-
-=item cbuilder_link
-
-Extra The L<ExtUtils::CBuilder> arguments passed in as a hash reference.
+The L<ExtUtils::ParseXS> arguments passes as a hash reference.
 
 =item verbose
 
 Spew copious debug information via test note.
 
-=item C++ or cpp
-
-[EXPERIMENTAL]
-
-XS should be compiled as C++.
-
 =back
 
 You can use the C<with_subtest> keyword to conditionally
@@ -977,34 +888,6 @@ Roy Storey
 
 Ilya Pavlov
 
-David Mertens (run4flat)
-
-Mark Nunberg (mordy, mnunberg)
-
-Christian Walde (Mithaldu)
-
-Brian Wightman (MidLifeXis)
-
-Zaki Mughal (zmughal)
-
-mohawk2
-
-Vikas N Kumar (vikasnkumar)
-
-Flavio Poletti (polettix)
-
-Salvador Fandiño (salva)
-
-Gianni Ceccarelli (dakkar)
-
-Pavel Shaydo (zwon, trinitum)
-
-Kang-min Liu (劉康民, gugod)
-
-Nicholas Shipp (nshp)
-
-Juan Julián Merelo Guervós (JJ)
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
