@@ -5,8 +5,7 @@ use warnings;
 use Test2::API qw( context );
 
 # ABSTRACT: Run object
-our $VERSION = '0.98_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '0.57'; # VERSION
 
 
 sub out    { shift->{out} }
@@ -173,11 +172,11 @@ Test::Alien::Run - Run object
 
 =head1 VERSION
 
-version 0.98_01
+version 0.57
 
 =head1 SYNOPSIS
 
- use Test2::V0;
+ use Test2::Extended::Bundle;
  use Test::Alien;
  
  run_ok([ $^X, -e => 'print "some output"; exit 22'])
@@ -303,34 +302,6 @@ Roy Storey
 
 Ilya Pavlov
 
-David Mertens (run4flat)
-
-Mark Nunberg (mordy, mnunberg)
-
-Christian Walde (Mithaldu)
-
-Brian Wightman (MidLifeXis)
-
-Zaki Mughal (zmughal)
-
-mohawk2
-
-Vikas N Kumar (vikasnkumar)
-
-Flavio Poletti (polettix)
-
-Salvador Fandiño (salva)
-
-Gianni Ceccarelli (dakkar)
-
-Pavel Shaydo (zwon, trinitum)
-
-Kang-min Liu (劉康民, gugod)
-
-Nicholas Shipp (nshp)
-
-Juan Julián Merelo Guervós (JJ)
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
