@@ -5,8 +5,7 @@ use warnings;
 use Test2::API qw( context );
 
 # ABSTRACT: A mock alien object for testing
-our $VERSION = '0.98_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '0.57'; # VERSION
 
 
 sub _def ($) { my($val) = @_; defined $val ? $val : '' }
@@ -15,14 +14,6 @@ sub cflags       { _def shift->{cflags}             }
 sub libs         { _def shift->{libs}               }
 sub dynamic_libs { @{ shift->{dynamic_libs} || [] } }
 
-sub runtime_prop
-{
-  my($self) = @_;
-  defined $self->{runtime_prop}
-    ? $self->{runtime_prop}
-    : {};
-}
-
 sub cflags_static
 {
   my($self) = @_;
@@ -59,7 +50,7 @@ Test::Alien::Synthetic - A mock alien object for testing
 
 =head1 VERSION
 
-version 0.98_01
+version 0.57
 
 =head1 SYNOPSIS
 
@@ -115,10 +106,6 @@ List reference containing the dynamic libraries.
 
 Tool binary directory.
 
-=head2 runtime_prop
-
-Runtime properties.
-
 =head1 EXAMPLE
 
 Here is a complete example using L<Alien::Libarchive> which is a non-L<Alien::Base>
@@ -200,34 +187,6 @@ Roy Storey
 
 Ilya Pavlov
 
-David Mertens (run4flat)
-
-Mark Nunberg (mordy, mnunberg)
-
-Christian Walde (Mithaldu)
-
-Brian Wightman (MidLifeXis)
-
-Zaki Mughal (zmughal)
-
-mohawk2
-
-Vikas N Kumar (vikasnkumar)
-
-Flavio Poletti (polettix)
-
-Salvador Fandiño (salva)
-
-Gianni Ceccarelli (dakkar)
-
-Pavel Shaydo (zwon, trinitum)
-
-Kang-min Liu (劉康民, gugod)
-
-Nicholas Shipp (nshp)
-
-Juan Julián Merelo Guervós (JJ)
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Graham Ollis.
